;;;vamri.asm
;; print ram dir status byte in hunam readable form
;$Id: vamri.asm,v 1.1 2011/08/17 04:33:27 goosey Exp goosey $

;Willard Goosey
;goosey@sdc.org 
;8/10/2011

;M100 RAM DIR status byte:
;bit 7 (msb)   1 if valid entry
;bit 6         1=ascii (DO)
;bit 5         1=machine language (CO)
;bit 4         1=ROM file
;bit 3	       1=invisible file
;bit 2	       reserved
;bit 1	       reserved
;bit 0	       internal use only

;VAMRI
;Valid
; Ascii
;  Machine
;   Rom
;    Invis

;VAMRI
;Entry Conditions:  A=status byte
;                   HL-> 8 byte buffer
;Exit Conditions: HL-> buffer
;		   BC destroyed

VMASK equ 80h
AMASK equ 40h
MMASK equ 20h
RMASK equ 10h
IMASK equ 8h

VALID equ 'V'
INVALID equ 'i'
ASCII equ 'A'
UNASCII equ 'b'
MACHINE equ 'M'
UNMACH equ '-'
ROM equ 'R'
RAM equ 'r'
INVIS equ 'I'
UNINVIS equ 'v'

vamri:	push h   ;save HL on stack
	push psw ;save AF on stack
	ani VMASK ;valid file?
	jz vamri1 ;jmp on not valid
	mvi m,VALID ;yes, valid file
	inx h       ;HL=HL+1

vamria  pop psw ;restore A
	push psw
	ani AMASK ;ascii file?
	jz vamri2 ;jmp not ascii
	mvi m,ASCII ;yes, ascii file
	inx h	    ;HL=HL+1

vamrim  pop psw     ;restore A
	push psw    ;save A
	ani MMASK ;ml file?
	jz vamri3   ;jump not ml
	mvi m,MACHINE ;yes, ml file
	inx h		;HL=HL+1

vamrir  pop psw		;load A
	push psw	;save A
	ani RMASK	;rom file?
	jz vamri4	;jmp not rom
	mvi m,ROM	;yes, rom file
	inx h		;HL=HL+1

vamrii  pop psw		;load A
	ani IMASK	;invis file?
	jz vamri5	;jmp not invis
	mvi m,INVIS	;yes, invis file

vamrid	pop h		;restore HL
	ret		;done


vamri1  mvi m,INVALID    ;invalid file
	inx h		 ;HL=HL+1
	jmp vamria	 ;check ascii flag

vamri2  mvi m,UNASCII	;not an ascii file
	inx h		;HL=HL+1
	jmp vamrim	;check ml flag

vamri3	mvi m,UNMACH	;not a ml file
	inx h		;HL=HL+1
	jmp vamrir	;check rom flag

vamri4  mvi m,RAM	;not a ROM file
	inx h
	jmp vamrii	;chek invis flag

vamri5	mvi m,UNINVIS	;not invis
	jmp vamrid	;done

;;;end of vamri.asm
